@@ -17,10 +17,10 @@ def update(quiet: bool, no_pull: bool) -> None:
             "pull nginx:mainline-alpine",
             check=True,
             quiet=quiet,
-            error_message="Pulling fresh image failed",
+            error_message="Pulling fresh image failed!",
         )
 
-    explain_step("Updating images of webserver Docker Swarm stack", quiet=quiet)
+    explain_step("Updating image of webserver Docker Swarm stack", quiet=quiet)
     docker(
         "service update --image nginx:mainline-alpine webserver_nginx",
         quiet=quiet,
